@@ -20,7 +20,7 @@ def hash_object(obj, base=64):
 	if base == 64:
 		return base64.b64encode(hash_maker.digest()).decode()
 	elif base == 32:
-		return base32hex.b32encode(hash_maker.digest()).replace('=', '-')
+		return base32hex.b32encode(hash_maker.digest()).replace('=', '-').replace('----', 'hb32')
 	else:
 		raise ValueError(f'base{base} is unknown!')
 
