@@ -141,7 +141,7 @@ def make_dataframe_hashable(data):
 	data = data
 	name = 'concat_column'
 	sep = '|'
-	return_data = True
+	return_data = False
 
 	if isinstance(data, SparkDF):
 		spark_compressed = concat_spark_columns(data=data, name=name, sep=sep, return_data=return_data)
